@@ -1,25 +1,9 @@
 /*
  * diald.c - Demand dialing daemon for ppp.
  *
- * Copyright (c) 1994 Eric Schenk.
- * All rights reserved.
- *
- * Permission is hereby granted, without written agreement and without
- * license or royalty fees, to use, copy, modify, and distribute this
- * software and its documentation for any purpose, provided that the
- * above copyright notice and the following two paragraphs appear in
- * all copies of this software.
- * 
- * IN NO EVENT SHALL ERIC SCHENK BE LIABLE TO ANY PARTY FOR
- * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
- * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF ERIC
- * SCHENK HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * ERIC SCHENK SPECIFICALLY DISCLAIMS ANY WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
- * ON AN "AS IS" BASIS, AND ERIC SCHENK HAS NO OBLIGATION TO
- * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
+ * Copyright (c) 1994, 1995 Eric Schenk.
+ * All rights reserved. Please see the file LICENSE which should be
+ * distributed with this software for terms of use.
  *
  * Portions of this code were derived from the code for pppd copyright
  * (c) 1989 Carnegie Mellon University. The copyright notice on this code
@@ -46,10 +30,12 @@
 
 /* intialized variables. */
 int modem_fd = -1;		/* modem device fp (for proxy reads) */
+FILE *mon_fp = 0;		/* monitor outut fd */
 int modem_hup = 0;		/* have we seen a modem HUP? */
 int delayed_quit = 0;		/* has the user requested a delayed quit? */
 int request_down = 0;		/* has the user requested link down? */
 int request_up = 0;		/* has the user requested link down? */
+int forced = 0;			/* has the user requested the link forced up? */
 int link_pid = 0;		/* current protocol control command pid */
 int dial_pid = 0;		/* current dial command pid */
 int dial_status = 0;		/* status from last dial command */
@@ -132,6 +118,7 @@ void main(int argc, char *argv[])
 	    if (state_timeout > 0) state_timeout--;
 	    if (debug&DEBUG_TICK)
 	        syslog(LOG_DEBUG,"--- tick --- state %d block %d",state,blocked);
+	    monitor_queue();
 	}
 	change_state();
     }
@@ -267,12 +254,14 @@ void get_pty(int *mfd, int *sfd)
  *	quit		- stop diald in its tracks.
  *	queue		- dump the filter queue.
  *	debug level	- set the debug level.
+ *	force		- force diald to put the connection up and keep it up.
+ *	unforce		- remove the forced up requirement.
  *	connect pid dev	- go up on a connection to the named port.
  *			  We assume the connection negotiations are
  *			  already finished and any lock files are in place.
  *			  When the connection should be killed we send a
  *			  SIGTERM to the given pid.
- *	bootp local remote - response from a bootp script
+ *	monitor file	- start a monitoring program.
  */
 
 void fifo_read()
@@ -295,6 +284,12 @@ void fifo_read()
 	   } else if (strcmp(buf,"unblock") == 0) {
 		syslog(LOG_INFO, "FIFO: Unblock request received.");
 		blocked = 0;
+	   } else if (strcmp(buf,"force") == 0) {
+		syslog(LOG_INFO, "FIFO: Force request received.");
+		forced = 1;
+	   } else if (strcmp(buf,"unforce") == 0) {
+		syslog(LOG_INFO, "FIFO: Unforce request received.");
+		forced = 0;
 	   } else if (strcmp(buf,"down") == 0) {
 		syslog(LOG_INFO, "FIFO: Link down request received.");
     		request_down = 1;
@@ -319,7 +314,27 @@ void fifo_read()
 	   } else if (sscanf(buf,"debug %d", &pid) == 1) {
     		syslog(LOG_INFO,"FIFO. Changing debug flags to %d.",pid);
 		debug = pid;
-	   } else if (sscanf(buf,"connect %d %n", &pid, &dev) == 2) {
+	   } else if (strncmp(buf,"monitor", 7) == 0) {
+    		struct stat sbuf;
+
+		if (mon_fp) { fclose(mon_fp); mon_fp = NULL; }
+		if (buf[7] != 0 && buf[7] == ' ') {
+		    syslog(LOG_INFO,"FIFO: monitor connection to %s requested",
+			    buf+8);
+		    if (stat(fifoname,&sbuf) < 0 || !sbuf.st_mode&S_IFIFO) {
+			syslog(LOG_INFO,"FIFO: %s not a pipe.",
+			    buf+8);
+		    } else if ((mon_fp = fopen(buf+8,"w"))==NULL) {
+			syslog(LOG_INFO,"FIFO: could not open pipe %s: %m",
+			    buf+8);
+			mon_fp = 0;
+		    } else {
+			output_state();
+		    }
+		} else {
+		    syslog(LOG_INFO,"FIFO: monitor connection closed");
+		}
+	   } else if (sscanf(buf,"connect %d %n", &pid, &dev) == 1) {
                if (pid > 1) {
 		   if (state != STATE_DOWN || req_pid) {
 		       /* somebody else already has this diald, tell 'em */
