@@ -1,3 +1,11 @@
+/*
+ * diald.h - Main header file.
+ *
+ * Copyright (c) 1994, 1995 Eric Schenk.
+ * All rights reserved. Please see the file LICENSE which should be
+ * distributed with this software for terms of use.
+ */
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>
@@ -19,13 +27,21 @@
 #include <sys/termios.h>
 #include <net/if.h>
 #include <netdb.h>
+/*
 #include <netinet/ip_tcp.h>
 #include <netinet/ip_udp.h>
 #include <netinet/ip_icmp.h>
-/* Shut up gcc about a redefinition that is harmless */
-#undef LITTLE_ENDIAN
 #include <netinet/ip.h>
 #include <netinet/in.h>
+*/
+#include <asm/byteorder.h>
+#include <linux/tcp.h>
+#include <linux/udp.h>
+#include <linux/icmp.h>
+/* Shut up gcc about a redefinition that is harmless */
+#undef LITTLE_ENDIAN
+#include <linux/ip.h>
+#include <linux/in.h>
 #include <arpa/inet.h>
 /* Hmm. Should there be a netinet pointer to this??? */
 #include <linux/if_ether.h>
@@ -129,6 +145,7 @@ int died_retry_count;
 /* Global variables */
 
 int fifo_fd;			/* FIFO command pipe. */
+FILE *mon_fp;			/* monitor output fp. */
 int proxy_mfd;			/* master pty fd */
 FILE *proxy_mfp;		/* also have an fp. Hackery for recv_packet. */
 int proxy_sfd;			/* slave pty fd */
@@ -136,7 +153,8 @@ int modem_fd;			/* modem device fp (for slip links) */
 char packet[4096];		/* slip packet buffer */
 int modem_hup;			/* have we seen a modem HUP? */
 int request_down;		/* has the user requested link down? */
-int request_up;			/* has the user requested link down? */
+int request_up;			/* has the user requested link up? */
+int forced;			/* has the user requested the link forced up? */
 int link_pid;			/* current pppd command pid */
 int dial_pid;			/* current dial command pid */
 int dial_status;		/* status from last dial command */
@@ -190,8 +208,10 @@ void sig_chld(int);
 void linkup(int);
 void die(int);
 void print_filter_queue(int);
+void monitor_queue(void);
 void become_daemon(void);
 void change_state(void);
+void output_state(void);
 void set_str(char **, char **);
 void set_int(int *, char **);
 void set_flag(int *, char **);
