@@ -1,25 +1,9 @@
 /*
  * filter.c - Packet filtering for diald.
  *
- * Copyright (c) 1994 Eric Schenk.
- * All rights reserved.
- *
- * Permission is hereby granted, without written agreement and without
- * license or royalty fees, to use, copy, modify, and distribute this
- * software and its documentation for any purpose, provided that the
- * above copyright notice and the following two paragraphs appear in
- * all copies of this software.
- * 
- * IN NO EVENT SHALL ERIC SCHENK BE LIABLE TO ANY PARTY FOR
- * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
- * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF ERIC
- * SCHENK HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * ERIC SCHENK SPECIFICALLY DISCLAIMS ANY WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
- * ON AN "AS IS" BASIS, AND ERIC SCHENK HAS NO OBLIGATION TO
- * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
+ * Copyright (c) 1994, 1995 Eric Schenk.
+ * All rights reserved. Please see the file LICENSE which should be
+ * distributed with this software for terms of use.
  */
 
 #include "diald.h"
@@ -139,3 +123,10 @@ void print_filter_queue(int sig)
     ctl_firewall(IP_FW_PCONN,&req);
     syslog(LOG_INFO,"--------------------------------------");
 }
+
+void monitor_queue()
+{
+    struct firewall_req req;
+    req.unit = fwunit;
+    ctl_firewall(IP_FW_MCONN,&req);
+}
