@@ -1,25 +1,9 @@
 /*
  * firewall.c - Packet filtering for diald.
  *
- * Copyright (c) 1994 Eric Schenk.
- * All rights reserved.
- *
- * Permission is hereby granted, without written agreement and without
- * license or royalty fees, to use, copy, modify, and distribute this
- * software and its documentation for any purpose, provided that the
- * above copyright notice and the following two paragraphs appear in
- * all copies of this software.
- * 
- * IN NO EVENT SHALL ERIC SCHENK BE LIABLE TO ANY PARTY FOR
- * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
- * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF ERIC
- * SCHENK HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * ERIC SCHENK SPECIFICALLY DISCLAIMS ANY WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
- * ON AN "AS IS" BASIS, AND ERIC SCHENK HAS NO OBLIGATION TO
- * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
+ * Copyright (c) 1994, 1995 Eric Schenk.
+ * All rights reserved. Please see the file LICENSE which should be
+ * distributed with this software for terms of use.
  */
 
 #include "diald.h"
@@ -74,7 +58,7 @@ static unsigned int in_slot(FW_Timeslot *slot, time_t *clock)
 #ifdef 0
     syslog(LOG_INFO,"slot def: %d %d %x %x %x",
 	slot->start, slot->end, slot->wday, slot->mday, slot->month);
-#endif
+#endif 0
 	if ((slot->start <= ctime)
 	&&  (ctime <= slot->end)
 	&&  (slot->wday & (1<<ltime->tm_wday))
@@ -149,8 +133,9 @@ static unsigned int slot_end_timeout(FW_Timeslot *slot, time_t *clock)
 	&& (slot->start <= ctime)
 	&& (ctime <= slot->end)) {
 	    /* Ok, this slot disjunct is active now */
-	    if (maxtime <= (slot->end - ctime))
-		maxtime = slot->end - ctime;
+	    int t = slot->end - ctime;
+	    if (maxtime <= t)
+		maxtime = t;
     	}
 	slot = slot->next;
     }
@@ -273,6 +258,7 @@ static void fw_force_update(FW_unit *unit)
 	if (fw->filt.type == FW_TYPE_UP || fw->filt.type == FW_TYPE_DOWN) {
 	    /* check when the rule is next applicable */
 	    timeout = slot_start_timeout(fw->filt.times,&clock);
+	
 	    if (timeout > 0) {
 		/* first time at which a previous slot starts */
 		if (timeout < mintime)
@@ -382,18 +368,17 @@ static void log_packet(int accept, struct iphdr *pkt, int len,  int rule)
 
     if (pkt->protocol == IPPROTO_TCP) {
 	syslog(LOG_INFO,
-	    "filter %s rule %d proto %d len %d seq %x ack %x flags %02x%s%s%s%s%s%s packet %s,%d => %s,%d",
+	    "filter %s rule %d proto %d len %d seq %x ack %x flags %s%s%s%s%s%s packet %s,%d => %s,%d",
 	    (accept)?"accepted":"ignored",rule,
 	    pkt->protocol,
 	    htons(pkt->tot_len),
-	    htonl(tcp->th_seq), htonl(tcp->th_ack),
-	    tcp->th_flags,
-	    (tcp->th_flags&TH_FIN) ? " FIN" : "",
-	    (tcp->th_flags&TH_SYN) ? " SYN" : "",
-	    (tcp->th_flags&TH_RST) ? " RST" : "",
-	    (tcp->th_flags&TH_PUSH) ? " PUSH" : "",
-	    (tcp->th_flags&TH_ACK) ? " ACK" : "",
-	    (tcp->th_flags&TH_URG) ? " URG" : "",
+	    htonl(tcp->seq), htonl(tcp->ack_seq),
+	    (tcp->fin) ? " FIN" : "",
+	    (tcp->syn) ? " SYN" : "",
+	    (tcp->rst) ? " RST" : "",
+	    (tcp->psh) ? " PUSH" : "",
+	    (tcp->ack) ? " ACK" : "",
+	    (tcp->urg) ? " URG" : "",
 	    saddr, sport, daddr, dport);
     } else {
 	syslog(LOG_INFO,
@@ -519,6 +504,11 @@ next_rule: /* try the next filter */
     return 1;
 }
 
+static void pcountdown(long secs)
+{
+    fprintf(mon_fp,"%02ld:%02ld:%02ld\n",secs/3600,(secs/60)%60,secs%60);
+}
+
 int ctl_firewall(int op, struct firewall_req *req)
 {
     FW_unit *unit;
@@ -621,6 +611,49 @@ int ctl_firewall(int op, struct firewall_req *req)
 	    return 0;
 	}
 	return 0;
+    case IP_FW_MCONN:
+	if (!req || !mon_fp) return -1; /* ERRNO */
+	{
+	    unsigned long atime = time(0);
+            unsigned long tstamp = timestamp();
+	    FW_Connection *c;
+	    char saddr[20], daddr[20];
+  	    int sport, dport;
+	    char proto[20];
+    	    struct protoent *pent;
+    	    struct in_addr addr;
+
+	    fprintf(mon_fp,"STATUS\n%d\n%d\n%d\n%d\n%d\n%d\n",
+		unit->up, unit->force, unit->impulse_mode,
+		impulse_init_time, impulse_time,
+		impulse_fuzz);
+	    pcountdown((unit->impulse_mode)?(unit->impulse.expected-tstamp):0);
+	    pcountdown(unit->force_etime-atime);
+	    pcountdown(next_alarm());
+	    fprintf(mon_fp,"QUEUE\n");
+	    for (c=unit->connections->next; c!=unit->connections; c=c->next) {
+                addr.s_addr = c->id.id[1] + (c->id.id[2]<<8)
+                        + (c->id.id[3]<<16) + (c->id.id[4]<<24);
+                strcpy(saddr,inet_ntoa(addr));
+                addr.s_addr = c->id.id[5] + (c->id.id[6]<<8)
+                        + (c->id.id[7]<<16) + (c->id.id[8]<<24);
+                strcpy(daddr,inet_ntoa(addr));
+		pent = getprotobynumber(c->id.id[0]);
+		if (pent) strcpy(proto,pent->p_name);
+		else sprintf(proto,"%d",c->id.id[0]);
+		sport = c->id.id[10]+(c->id.id[9]<<8);
+		dport = c->id.id[12]+(c->id.id[11]<<8);
+                fprintf(mon_fp,
+                        "%-4s  %15s/%-5d  %15s/%-5d  ",
+                        proto, saddr, sport,
+                        daddr, dport);
+		pcountdown(c->timer.expected-tstamp);
+	    }
+	    fprintf(mon_fp,"END QUEUE\n");
+	    fflush(mon_fp);
+	    return 0;
+	}
+	return 0;
     case IP_FW_PPRULE:
 	if (!req) return -1; /* ERRNO */
 	return 0;
