@@ -1,3 +1,11 @@
+/*
+ * firewall.h - Firewall headers.
+ *
+ * Copyright (c) 1994, 1995 Eric Schenk.
+ * All rights reserved. Please see the file LICENSE which should be
+ * distributed with this software for terms of use.
+ */
+
 #define FW_ID_LEN 16			/* number of bytes in a connection id */
 #define FW_OFFSET(x) ((x)&0x7f)		/* offset into a header */
 #define FW_IP_OFFSET(x) ((x)&0x7f)	/* construct a ip header offset */
@@ -104,6 +112,7 @@ struct firewall_req {
 #define IP_FW_CLOSE	11	/* print the filters */
 #define IP_FW_UP	12	/* mark the interface as up */
 #define IP_FW_DOWN	13	/* mark the interface as down */
+#define IP_FW_MCONN	14	/* print the connections to monitor */
 
 /*
  * Internal data structures.
