@@ -1,27 +1,11 @@
 /*
  * fsm.c - Control Finite State Machine for diald main loop.
  *
- * Copyright (c) 1994 Eric Schenk.
- * All rights reserved.
- *
- * Permission is hereby granted, without written agreement and without
- * license or royalty fees, to use, copy, modify, and distribute this
- * software and its documentation for any purpose, provided that the
- * above copyright notice and the following two paragraphs appear in
- * all copies of this software.
- * 
- * IN NO EVENT SHALL ERIC SCHENK BE LIABLE TO ANY PARTY FOR
- * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
- * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF ERIC
- * SCHENK HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * ERIC SCHENK SPECIFICALLY DISCLAIMS ANY WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
- * ON AN "AS IS" BASIS, AND ERIC SCHENK HAS NO OBLIGATION TO
- * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
- *
+ * Copyright (c) 1994, 1995 Eric Schenk.
+ * All rights reserved. Please see the file LICENSE which should be
+ * distributed with this software for terms of use.
  */
+
 #include "diald.h"
 
 #define STATE(name,timeout,tstate) \
@@ -60,8 +44,8 @@ void trans_DOWN(void)
 {
     request_down = 0;
     if (request_up && !blocked) {request_up = 0; GOTO(STATE_CONNECT);}
-    else if (!queue_empty() && !blocked) GOTO(STATE_CONNECT);
-    else if (delayed_quit && queue_empty()) {
+    else if ((forced || !queue_empty()) && !blocked) GOTO(STATE_CONNECT);
+    else if (delayed_quit && queue_empty() && !forced) {
 	syslog(LOG_INFO,"Carrying out delayed termination request.");
 	terminate = 1;
     }
@@ -89,6 +73,7 @@ void act_CONNECT(void)
 	fclose(acctfp);
     }
     txtotal = rxtotal = 0;
+    dial_status = 0;
     open_modem();
 }
 void trans_CONNECT(void)
@@ -109,7 +94,10 @@ void act_STOP_DIAL(void)
         if (debug&DEBUG_VERBOSE)
             syslog(LOG_INFO,"Sending SIGINT to (dis)connect process %d",
 		dial_pid);
-        kill(dial_pid,SIGINT);
+	if (kill(dial_pid,SIGINT) == -1 && errno == ESRCH) {
+	    dial_pid = 0;
+	    dial_status = -1;
+	}
     }
 }
 void trans_STOP_DIAL(void)
@@ -124,7 +112,10 @@ void act_KILL_DIAL(void)
         if (debug&DEBUG_VERBOSE)
             syslog(LOG_INFO,"Sending SIGKILL to (dis)connect process %d",
 		dial_pid);
-        kill(dial_pid,SIGKILL);
+	if (kill(dial_pid,SIGKILL) == -1 && errno == ESRCH) {
+	    dial_pid = 0;
+	    dial_status = -1;
+	}
     }
 }
 void trans_KILL_DIAL(void)
@@ -198,7 +189,7 @@ void trans_UP(void)
 	goto take_link_down;
     }
     if (state_timeout == 0) {
-	if (queue_empty()) {  /* the link may be forced up. */
+	if (!forced && queue_empty()) {  /* the link may be forced up. */
 	    syslog(LOG_INFO,"%s %d %s",
 	    	"Failed to received first packet within",
 	    	first_packet_timeout,
@@ -207,7 +198,7 @@ void trans_UP(void)
 	}
 	state_timeout = -1;
     }
-    if (queue_empty() && state_timeout == -1) {
+    if (!forced && queue_empty() && state_timeout == -1) {
 	syslog(LOG_INFO,"Closing down idle link.");
 take_link_down:
 	current_retry_count = 0;
@@ -317,6 +308,14 @@ struct {
     STATE(ERROR, 0, ERROR)
 };
 
+void output_state()
+{
+    if (mon_fp) {
+	fprintf(mon_fp,"STATE\n%s\n",trans[state].name);
+	fflush(mon_fp);
+    }
+}
+
 void GOTO(int new_state)
 {
     state_timeout = (trans[new_state].timeout)
@@ -325,10 +324,10 @@ void GOTO(int new_state)
     	syslog(LOG_DEBUG,"new state %s action %d timeout %d",
 	    trans[new_state].name,trans[new_state].action,state_timeout);
     state = new_state;
+    output_state();
     (*trans[new_state].action)();
 }
 
-
 /*
  * Change the state according to the current state and events.
  */
