@@ -1,25 +1,9 @@
 /*
  * modem.c - Modem control functions.
  *
- * Copyright (c) 1994 Eric Schenk.
- * All rights reserved.
- *
- * Permission is hereby granted, without written agreement and without
- * license or royalty fees, to use, copy, modify, and distribute this
- * software and its documentation for any purpose, provided that the
- * above copyright notice and the following two paragraphs appear in
- * all copies of this software.
- * 
- * IN NO EVENT SHALL ERIC SCHENK BE LIABLE TO ANY PARTY FOR
- * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
- * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF ERIC
- * SCHENK HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * ERIC SCHENK SPECIFICALLY DISCLAIMS ANY WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
- * ON AN "AS IS" BASIS, AND ERIC SCHENK HAS NO OBLIGATION TO
- * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
+ * Copyright (c) 1994, 1995 Eric Schenk.
+ * All rights reserved. Please see the file LICENSE which should be
+ * distributed with this software for terms of use.
  *
  * Portions of this code were derived from the code for pppd copyright
  * (c) 1989 Carnegie Mellon University. The copyright notice on this code
@@ -240,6 +224,7 @@ void open_modem()
 
     modem_hup = 0;
     modem_fd = -1;
+    dial_status = 0;
 
     if (req_pid) {
 	/* The user has specified a device. Use it, no search or lock needed. */
