@@ -1,25 +1,9 @@
 /*
  * ppp.c - ppp and pppd control.
  *
- * Copyright (c) 1994 Eric Schenk.
- * All rights reserved.
- *
- * Permission is hereby granted, without written agreement and without
- * license or royalty fees, to use, copy, modify, and distribute this
- * software and its documentation for any purpose, provided that the
- * above copyright notice and the following two paragraphs appear in
- * all copies of this software.
- * 
- * IN NO EVENT SHALL ERIC SCHENK BE LIABLE TO ANY PARTY FOR
- * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
- * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF ERIC
- * SCHENK HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * ERIC SCHENK SPECIFICALLY DISCLAIMS ANY WARRANTIES,
- * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
- * ON AN "AS IS" BASIS, AND ERIC SCHENK HAS NO OBLIGATION TO
- * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
+ * Copyright (c) 1994, 1995 Eric Schenk.
+ * All rights reserved. Please see the file LICENSE which should be
+ * distributed with this software for terms of use.
  */
 
 #include "diald.h"
@@ -169,7 +153,9 @@ int ppp_dead()
 
 void ppp_stop()
 {
-    if (link_pid) kill(link_pid,SIGINT);
+    if (link_pid)
+    	if (kill(link_pid,SIGINT) == -1 && errno == ESRCH)
+	    link_pid = 0;
 }
 
 void ppp_reroute()
@@ -189,5 +175,7 @@ void ppp_reroute()
 
 void ppp_kill()
 {
-    if (link_pid) kill(link_pid,SIGKILL);
+    if (link_pid)
+    	if (kill(link_pid,SIGINT) == -1 && errno == ESRCH)
+	    link_pid = 0;
 }
